@@ -40,11 +40,11 @@ axes.coords[1].set_axislabel("Latitude [deg]")
 axes.coords.grid(color='black', alpha=0.6, linestyle='dotted', linewidth=0.5)
 
 cb = plt.colorbar(im, fraction=0.019, pad=0.1)
-cb.set_label("Radial magnetic field [Gauss]")
+cb.set_label(f"Radial magnetic field [{syn_map.unit}]")
 
 # In order to make the x-axis ticks show, the bottom y-limit has to be adjusted slightly
 axes.set_ylim(bottom=0)
-axes.set_title("{} {}-{}".format(syn_map.meta['content'], syn_map.meta['CAR_ROT'],
-                                 syn_map.meta['CAR_ROT'] + 1))
+axes.set_title(f"{syn_map.meta['content']},\n"
+               f"Carrington rotation {syn_map.meta['CAR_ROT']}")
 
 plt.show()
